@@ -23,7 +23,6 @@
 #' @importFrom purrr pmap
 #' @importFrom stats lm
 #' @importFrom stats as.formula
-#' @importFrom tibble as_data_frame
 #' @importFrom tidyr nest
 #' @importFrom dplyr select
 #' @importFrom dplyr group_by
@@ -39,7 +38,7 @@
 #' @seealso grouped_lm
 #'
 #' @examples
-#' 
+#'
 #' # in case of just one grouping variable
 #' groupedstats::grouped_slr(
 #'   data = iris,
@@ -127,17 +126,17 @@ grouped_slr <- function(data,
           dplyr::filter(.data = broom::tidy(x = .), term == !!filter_name), # remove intercept terms
           broom::confint_tidy(x = .)[-c(1), ]
         ),
-        .id = "group"
+        .id = "..group"
       ) %>% # removing the unnecessary term column
       dplyr::select(.data = ., -term) %>% # convert to a tibble dataframe
-      tibble::as_data_frame(x = .)
+      tibble::as_tibble(x = .)
 
     # preparing the final dataframe to be returned
     results_df %<>%
       dplyr::mutate(.data = ., formula = as.character(fx_plain)) %>% # rearrange the dataframe
       dplyr::select(
         .data = .,
-        group,
+        `..group`,
         formula,
         t.value = statistic,
         estimate,
@@ -146,7 +145,7 @@ grouped_slr <- function(data,
         std.error,
         p.value
       ) %>% # convert to a tibble dataframe
-      tibble::as_data_frame(x = .)
+      tibble::as_tibble(x = .)
 
     # return the dataframe
     return(results_df)
@@ -156,10 +155,10 @@ grouped_slr <- function(data,
 
   # converting the original dataframe to have a grouping variable column
   df %<>%
-    tibble::rownames_to_column(., var = "group")
+    tibble::rownames_to_column(., var = "..group")
 
   # running custom function for each element of the created list column
-  df_lm <- purrr::pmap(
+  combined_df <- purrr::pmap(
     .l = list(
       list.col = list(df$data),
       x_name = purrr::map(
@@ -174,13 +173,13 @@ grouped_slr <- function(data,
     .f = lm_listed
   ) %>%
     dplyr::bind_rows(.) %>%
-    dplyr::left_join(x = ., y = df, by = "group") %>%
+    dplyr::left_join(x = ., y = df, by = "..group") %>%
     dplyr::select(.data = ., !!!grouping.vars, dplyr::everything()) %>%
-    dplyr::select(.data = ., -group, -data) %>%
+    dplyr::select(.data = ., -`..group`, -data) %>%
     signif_column(data = ., p = `p.value`)
 
   # ============================== output ==================================
 
   # return the final dataframe with results
-  return(df_lm)
+  return(combined_df)
 }
